# Copyright 2019-2022 Le Filament (<https://le-filament.com>)
# License AGPL-3.0 or later (http://www.gnu.org/licenses/agpl.html).

from odoo import api, fields, models


class TrainingProgram(models.Model):
    _name = "training.course"
    _description = "Training courses"
    _inherit = "mail.thread"

    name = fields.Char(
        string="Nom",
        required=True,
    )
    description = fields.Text()
    objective = fields.Text(string="Objectif")
    method = fields.Text(string="Méthodologie")
    means = fields.Text(string="Moyens Pédagogiques")
    control = fields.Text(string="Suivi")
    evaluation = fields.Text(string="Modalités évaluation")
    nature = fields.Text(string="Nature de l'action")
    acquis = fields.Text(string="Acquis de la formation")
    students_profile = fields.Text(string="Profil des stagiaires")
    prerequisites = fields.Text(string="Pré-requis")
    session_ids = fields.Many2many(
        comodel_name="training.course.session",
        relation="program_course_rel",
        column1="program_id",
        column2="course_id",
        string="Sessions",
    )
    duration_total = fields.Integer(
        string="Durée totale", compute="_compute_sessions", default=0, store=True
    )
    session_count = fields.Integer(
        string="Nb Sessions", compute="_compute_sessions", default=0, store=True
    )

    # ------------------------------------------------------
    # Compute
    # ------------------------------------------------------
    @api.depends("session_ids")
    def _compute_sessions(self):
        self.session_count = len(self.session_ids)
        self.duration_total = sum(self.session_ids.mapped("duration"))


class TrainingProgramSession(models.Model):
    _name = "training.course.session"
    _description = "Training course sessions"

    name = fields.Char(
        string="Nom",
        required=True,
    )
    description = fields.Text()
    course_id = fields.Many2many(
        comodel_name="training.course",
        relation="program_course_rel",
        column1="course_id",
        column2="program_id",
        string="Programmes",
    )
    duration = fields.Integer(string="Durée (h)", default=4)
    sequence = fields.Integer(string="Séquence", default=10)
