# Copyright 2019-2022 Le Filament (<https://le-filament.com>)
# License AGPL-3.0 or later (http://www.gnu.org/licenses/agpl.html).

from odoo import api, fields, models


class TrainingStudent(models.Model):
    _name = "training.student"
    _description = "Training Students"

    student_id = fields.Many2one(
        comodel_name="res.partner",
        string="Stagiaire",
        required=True,
        domain=[("is_company", "=", False)],
    )
    parent_id = fields.Many2one(
        comodel_name="res.partner",
        string="Entreprise",
        domain=[("is_company", "=", True)],
    )
    training_id = fields.Many2one(comodel_name="training.training", string="Formation")
    certificate = fields.Binary(string="Attestation")

    _sql_constraints = [
        (
            "course_unique",
            "UNIQUE(student_id, training_id)",
            "Un stagiaire ne peut être inscrit qu'une fois",
        )
    ]

    # ------------------------------------------------------
    # Onchange
    # ------------------------------------------------------
    @api.onchange("parent_id")
    def _onchange_student_id(self):
        vals = {}
        vals["domain"] = {
            "student_id": [
                ("is_company", "=", False),
                ("parent_id", "=", self.parent_id.id),
            ],
        }
        return vals
